==> google-cloud-sdk-518.0.0-darwin-arm.tar.gz: google-cloud-sdk/lib/surface/deploy/job_runs/terminate.py <==
# -*- coding: utf-8 -*- #
# Copyright 2023 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Terminates a Cloud Deploy job run."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.clouddeploy import job_run
from googlecloudsdk.api_lib.util import exceptions as gcloud_exception
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.deploy import deploy_policy_util
from googlecloudsdk.command_lib.deploy import exceptions as deploy_exceptions
from googlecloudsdk.command_lib.deploy import flags
from googlecloudsdk.command_lib.deploy import resource_args
from googlecloudsdk.core import log


_DETAILED_HELP = {
    'DESCRIPTION': '{description}',
    'EXAMPLES': """ \
    To terminate a job run `test-jobrun`, for delivery pipeline 'test-pipeline', release 'test-release', rollout 'test-rollout', in region 'us-central1', run:

      $ {command} test-jobrun --delivery-pipeline=test-pipeline --release=test-release --rollout=test-rollout --region=us-central1

""",
}


@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
)
class Terminate(base.UpdateCommand):
  """Terminates a Cloud Deploy job run."""

  detailed_help = _DETAILED_HELP

  @staticmethod
  def Args(parser):
    resource_args.AddJobRunResourceArg(parser, positional=True)
    flags.AddOverrideDeployPolicies(parser)

  @gcloud_exception.CatchHTTPErrorRaiseHTTPException(
      deploy_exceptions.HTTP_ERROR_FORMAT
  )
  def Run(self, args):
    job_run_ref = args.CONCEPTS.job_run.Parse()

    log.status.Print(
        'Terminating job run {}.\n'.format(job_run_ref.RelativeName())
    )
    # On the command line deploy policy IDs are provided, but for the
    # Terminate API we need to provide the full resource name.
    pipeline_ref = job_run_ref.Parent().Parent().Parent()
    policies = deploy_policy_util.CreateDeployPolicyNamesFromIDs(
        pipeline_ref, args.override_deploy_policies
    )

    return job_run.JobRunsClient().Terminate(
        name=job_run_ref.RelativeName(),
        override_deploy_policies=policies,
    )

==> google-cloud-sdk-552.0.0-darwin-arm.tar.gz: google-cloud-sdk/lib/surface/deploy/job_runs/terminate.py <==
# -*- coding: utf-8 -*- #
# Copyright 2023 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Terminates a Cloud Deploy job run."""


from googlecloudsdk.api_lib.clouddeploy import job_run
from googlecloudsdk.api_lib.util import exceptions as gcloud_exception
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.deploy import deploy_policy_util
from googlecloudsdk.command_lib.deploy import exceptions as deploy_exceptions
from googlecloudsdk.command_lib.deploy import flags
from googlecloudsdk.command_lib.deploy import resource_args
from googlecloudsdk.core import log


_DETAILED_HELP = {
    'DESCRIPTION': '{description}',
    'EXAMPLES': """ \
    To terminate a job run `test-jobrun`, for delivery pipeline 'test-pipeline', release 'test-release', rollout 'test-rollout', in region 'us-central1', run:

      $ {command} test-jobrun --delivery-pipeline=test-pipeline --release=test-release --rollout=test-rollout --region=us-central1

""",
}


@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
)
@base.DefaultUniverseOnly
class Terminate(base.UpdateCommand):
  """Terminates a Cloud Deploy job run."""

  detailed_help = _DETAILED_HELP

  @staticmethod
  def Args(parser):
    resource_args.AddJobRunResourceArg(parser, positional=True)
    flags.AddOverrideDeployPolicies(parser)

  @gcloud_exception.CatchHTTPErrorRaiseHTTPException(
      deploy_exceptions.HTTP_ERROR_FORMAT
  )
  def Run(self, args):
    job_run_ref = args.CONCEPTS.job_run.Parse()

    log.status.Print(
        'Terminating job run {}.\n'.format(job_run_ref.RelativeName())
    )
    # On the command line deploy policy IDs are provided, but for the
    # Terminate API we need to provide the full resource name.
    pipeline_ref = job_run_ref.Parent().Parent().Parent()
    policies = deploy_policy_util.CreateDeployPolicyNamesFromIDs(
        pipeline_ref, args.override_deploy_policies
    )

    return job_run.JobRunsClient().Terminate(
        name=job_run_ref.RelativeName(),
        override_deploy_policies=policies,
    )
